==> mah-jong_1.11.orig.tar.gz: mj-1.11-src/gtkrc.h <==
/* the minimal style definitions required for functionality */
static char *gtkrc_minimal_styles =
"style \"table\" {\n"
"	bg[NORMAL] = \"darkgreen\"\n"
"}\n"
"style \"playerlabel\" {\n"
"       fg[NORMAL] = \"white\"\n"
"}\n"
"\n"
"style \"claim\" {\n"
"	bg[NORMAL] = \"yellow\"\n"
"	font_name = \"Sans Bold 20px\"\n"
"}\n"
"\n"
"binding \"topwindow\" {\n"
"	bind \"Left\" {\n"
"		\"selectleft\"()\n"
"	}\n"
"	bind \"Right\" {\n"
"		\"selectright\"()\n"
"	}\n"
"	bind \"<shift>Left\" {" "\n"
"		\"moveleft\"()" "\n"
"	}" "\n"
"	bind \"<shift>Right\" {" "\n"
"		\"moveright\"()" "\n"
"	}" "\n"
"}\n"
"\n"
"style \"text\" {\n"
"}\n"
"widget \"*.table\" style \"table\"" "\n"
"widget \"*.claim\" style \"claim\"" "\n"
"widget \"topwindow\" binding \"topwindow\"" "\n"
"widget \"*.GtkTextView*\" style \"text\"" "\n"
"widget \"*.GtkEntry*\" style \"text\"" "\n"
"widget \"*.playerlabel\" style \"playerlabel\"" "\n"
  ;

/* style settings when no clearlooks is available. Supposed to look
   more or less like the GTK1 default. */
static char *gtkrc_plain_styles =
#ifdef WIN32
"gtk-font-name = \"Sans 12px\"\n"
#else
"gtk-font-name = \"Verdana Condensed 12px\"\n"
#endif
"\n"
"style \"default\" { \n"
"	bg[NORMAL] = \"#CCC\"\n"
"	fg[NORMAL] = \"#000\"\n"
"	bg[PRELIGHT] = \"#EEE\"\n"
"	fg[PRELIGHT] = \"#000\"\n"
"	bg[ACTIVE] = \"#AAA\"\n"
"	fg[ACTIVE] = \"#000\"\n"
"	bg[SELECTED] = \"#228\"\n"
"	fg[SELECTED] = \"#FFF\"\n"
"	bg[INSENSITIVE] = \"#888\"\n"
"	fg[INSENSITIVE] = \"#444\"\n"
"	xthickness = 2\n"
"	ythickness = 2\n"
"}\n"
"\n"
"widget \"*\" style \"default\"\n"
"\n"
"style \"table\" {\n"
"	bg[NORMAL] = \"darkgreen\"\n"
"}\n"
"style \"playerlabel\" {\n"
"       fg[NORMAL] = \"white\"\n"
"}\n"
"\n"
"style \"tile\" {\n"
"	bg[NORMAL] = \"white\"\n"
"	fg[NORMAL] = \"black\"\n"
"	xthickness = 1\n"
" 	ythickness = 1\n"
"	GtkButton::inner-border = { 0, 0, 0, 0 }\n"
"}\n"
"\n"
"style \"mytile\" {\n"
"	bg[NORMAL] = \"white\"\n"
"	bg[PRELIGHT] = \"yellow\"\n"
"	bg[ACTIVE] = \"#444\"\n"
"	GtkButton::inner-border = { 0, 0, 0, 0 }\n"
"	xthickness = 1\n"
" 	ythickness = 1\n"
"}\n"
"\n"
"style \"claim\" {\n"
"	bg[NORMAL] = \"yellow\"\n"
"	font_name = \"Sans Bold 20px\"\n"
"}\n"
"\n"
"binding \"topwindow\" {\n"
"	bind \"Left\" {\n"
"		\"selectleft\"()\n"
"	}\n"
"	bind \"Right\" {\n"
"		\"selectright\"()\n"
"	}\n"
"	bind \"<shift>Left\" {" "\n"
"		\"moveleft\"()" "\n"
"	}" "\n"
"	bind \"<shift>Right\" {" "\n"
"		\"moveright\"()" "\n"
"	}" "\n"
"}\n"
"\n"
"style \"text\" {\n"
"	font_name = \"Courier New 16px\"\n"
"}\n"
  ;

/* style settings when clearlooks is available */
static char *gtkrc_clearlooks_styles =
"########### from here on is overrides to the Clearlooks theme." "\n"
"" "\n"
#ifdef WIN32
"gtk-font-name = \"Sans 12px\"\n"
#else
"gtk-font-name = \"Verdana Condensed 12px\"\n"
#endif
"" "\n"
"style \"table\" {" "\n"
"	bg[NORMAL] = \"darkgreen\"" "\n"
"}" "\n"
"style \"playerlabel\" {\n"
"       fg[NORMAL] = \"white\"\n"
"}\n"
"" "\n"
"style \"tile\" {" "\n"
"	bg[NORMAL] = \"white\"" "\n"
"	xthickness = 0" "\n"
" 	ythickness = 0" "\n"
"}" "\n"
"" "\n"
"style \"mytile\" {" "\n"
"	bg[NORMAL] = \"white\"" "\n"
"	bg[PRELIGHT] = \"yellow\"" "\n"
"	bg[ACTIVE] = \"#444\"" "\n"
"	xthickness = 0" "\n"
" 	ythickness = 0" "\n"
"}" "\n"
"" "\n"
"style \"claim\" {" "\n"
"	bg[NORMAL] = \"yellow\"" "\n"
"	font_name = \"Sans Bold 20px\"" "\n"
"}" "\n"
"" "\n"
"binding \"topwindow\" {" "\n"
"	bind \"Left\" {" "\n"
"		\"selectleft\"()" "\n"
"	}" "\n"
"	bind \"Right\" {" "\n"
"		\"selectright\"()" "\n"
"	}" "\n"
"	bind \"<shift>Left\" {" "\n"
"		\"moveleft\"()" "\n"
"	}" "\n"
"	bind \"<shift>Right\" {" "\n"
"		\"moveright\"()" "\n"
"	}" "\n"
"}" "\n"
"" "\n"
"style \"text\" {" "\n"
"	font_name = \"Courier New 16px\"" "\n"
"}" "\n"
  ; 
static char *gtkrc_apply_styles =
"widget \"*.table\" style \"table\"" "\n"
"widget \"*.tile\" style \"tile\"" "\n"
"widget \"*.mytile\" style \"mytile\"" "\n"
"widget \"*.claim\" style \"claim\"" "\n"
"widget \"topwindow\" binding \"topwindow\"" "\n"
"widget \"*.GtkTextView*\" style \"text\"" "\n"
"widget \"*.GtkEntry*\" style \"text\"" "\n"
"widget \"*.playerlabel\" style \"playerlabel\"" "\n"
;

==> mah-jong_1.17.2.orig.tar.gz: mj-1.17.2-src/gtkrc.h <==
/* the minimal style definitions required for functionality */
static char *gtkrc_minimal_styles =
"style \"table\" {\n"
"	bg[NORMAL] = \"darkgreen\"\n"
"}\n"
"style \"playerlabel\" {\n"
"       fg[NORMAL] = \"white\"\n"
"}\n"
"\n"
"style \"claim\" {\n"
"	bg[NORMAL] = \"yellow\"\n"
"	font_name = \"Sans Bold 20px\"\n"
"}\n"
"style \"thinking\" {\n"
"	fg[NORMAL] = \"yellow\"\n"
"	font_name = \"Sans Bold 20px\"\n"
"}\n"
"\n"
"binding \"topwindow\" {\n"
"	bind \"Left\" {\n"
"		\"selectleft\"()\n"
"	}\n"
"	bind \"Right\" {\n"
"		\"selectright\"()\n"
"	}\n"
"	bind \"<shift>Left\" {" "\n"
"		\"moveleft\"()" "\n"
"	}" "\n"
"	bind \"<shift>Right\" {" "\n"
"		\"moveright\"()" "\n"
"	}" "\n"
"}\n"
"\n"
"style \"text\" {\n"
"}\n"
"widget \"*.table\" style \"table\"" "\n"
"widget \"*.claim\" style \"claim\"" "\n"
"widget \"*.think\" style \"thinking\"\n"
"widget \"topwindow\" binding \"topwindow\"" "\n"
"widget \"*.GtkTextView*\" style \"text\"" "\n"
"widget \"*.GtkEntry*\" style \"text\"" "\n"
"widget \"*.playerlabel\" style \"playerlabel\"" "\n"
  ;

/* style settings when no clearlooks is available. Supposed to look
   more or less like the GTK1 default. */
static char *gtkrc_plain_styles =
#ifdef WIN32
"gtk-font-name = \"Sans 12px\"\n"
#else
"gtk-font-name = \"Verdana Condensed 12px\"\n"
#endif
"\n"
"style \"default\" { \n"
"	bg[NORMAL] = \"#CCC\"\n"
"	fg[NORMAL] = \"#000\"\n"
"	bg[PRELIGHT] = \"#EEE\"\n"
"	fg[PRELIGHT] = \"#000\"\n"
"	bg[ACTIVE] = \"#AAA\"\n"
"	fg[ACTIVE] = \"#000\"\n"
"	bg[SELECTED] = \"#228\"\n"
"	fg[SELECTED] = \"#FFF\"\n"
"	bg[INSENSITIVE] = \"#888\"\n"
"	fg[INSENSITIVE] = \"#444\"\n"
"	xthickness = 2\n"
"	ythickness = 2\n"
"}\n"
"\n"
"widget \"*\" style \"default\"\n"
"\n"
"style \"table\" {\n"
"	bg[NORMAL] = \"darkgreen\"\n"
"}\n"
"style \"playerlabel\" {\n"
"       fg[NORMAL] = \"white\"\n"
"}\n"
"\n"
"style \"tile\" {\n"
"	bg[NORMAL] = \"white\"\n"
"	fg[NORMAL] = \"black\"\n"
"	xthickness = 1\n"
" 	ythickness = 1\n"
"	GtkButton::inner-border = { 0, 0, 0, 0 }\n"
"}\n"
"\n"
"style \"mytile\" {\n"
"	bg[NORMAL] = \"white\"\n"
"	bg[PRELIGHT] = \"yellow\"\n"
"	bg[ACTIVE] = \"magenta\"\n"
"	GtkButton::inner-border = { 0, 0, 0, 0 }\n"
"	xthickness = 1\n"
" 	ythickness = 1\n"
"}\n"
"\n"
"style \"claim\" {\n"
"	bg[NORMAL] = \"yellow\"\n"
"	font_name = \"Sans Bold 20px\"\n"
"}\n"
"style \"thinking\" {\n"
"	fg[NORMAL] = \"yellow\"\n"
"	font_name = \"Sans Bold 20px\"\n"
"}\n"
"\n"
"binding \"topwindow\" {\n"
"	bind \"Left\" {\n"
"		\"selectleft\"()\n"
"	}\n"
"	bind \"Right\" {\n"
"		\"selectright\"()\n"
"	}\n"
"	bind \"<shift>Left\" {" "\n"
"		\"moveleft\"()" "\n"
"	}" "\n"
"	bind \"<shift>Right\" {" "\n"
"		\"moveright\"()" "\n"
"	}" "\n"
"}\n"
"\n"
"style \"text\" {\n"
"	font_name = \"Courier New 16px\"\n"
"}\n"
  ;

/* style settings when clearlooks is available */
static char *gtkrc_clearlooks_styles =
"########### from here on is overrides to the Clearlooks theme." "\n"
"" "\n"
#ifdef WIN32
"gtk-font-name = \"Sans 12px\"\n"
#else
"gtk-font-name = \"Verdana Condensed 12px\"\n"
#endif
"" "\n"
"style \"table\" {" "\n"
"	bg[NORMAL] = \"darkgreen\"" "\n"
"}" "\n"
"style \"playerlabel\" {\n"
"       fg[NORMAL] = \"white\"\n"
"}\n"
"" "\n"
"style \"tile\" {" "\n"
"	bg[NORMAL] = \"white\"" "\n"
"	xthickness = 0" "\n"
" 	ythickness = 0" "\n"
"}" "\n"
"" "\n"
"style \"mytile\" {" "\n"
"	bg[NORMAL] = \"white\"" "\n"
"	bg[PRELIGHT] = \"yellow\"" "\n"
"	bg[ACTIVE] = \"magenta\"" "\n"
"	xthickness = 1" "\n"
" 	ythickness = 1" "\n"
"}" "\n"
"" "\n"
"style \"claim\" {" "\n"
"	bg[NORMAL] = \"yellow\"" "\n"
"	font_name = \"Sans Bold 20px\"" "\n"
"}" "\n"
"style \"thinking\" {" "\n"
"	fg[NORMAL] = \"yellow\"" "\n"
"	font_name = \"Sans Bold 20px\"" "\n"
"}" "\n"
"" "\n"
"binding \"topwindow\" {" "\n"
"	bind \"Left\" {" "\n"
"		\"selectleft\"()" "\n"
"	}" "\n"
"	bind \"Right\" {" "\n"
"		\"selectright\"()" "\n"
"	}" "\n"
"	bind \"<shift>Left\" {" "\n"
"		\"moveleft\"()" "\n"
"	}" "\n"
"	bind \"<shift>Right\" {" "\n"
"		\"moveright\"()" "\n"
"	}" "\n"
"}" "\n"
"" "\n"
"style \"text\" {" "\n"
"	font_name = \"Courier New 16px\"" "\n"
"}" "\n"
  ; 
static char *gtkrc_apply_styles =
"widget \"*.table\" style \"table\"" "\n"
"widget \"*.tile\" style \"tile\"" "\n"
"widget \"*.mytile\" style \"mytile\"" "\n"
"widget \"*.claim\" style \"claim\"" "\n"
"widget \"*.think\" style \"thinking\"" "\n"
"widget \"topwindow\" binding \"topwindow\"" "\n"
"widget \"*.GtkTextView*\" style \"text\"" "\n"
"widget \"*.GtkEntry*\" style \"text\"" "\n"
"widget \"*.playerlabel\" style \"playerlabel\"" "\n"
;
